@@ -1,5 +1,6 @@
+import datetime
 from dataclasses import dataclass
-from typing import List, Optional
+from typing import Dict, List, Optional, Union
 from ddd_objects.infrastructure.do import BaseDO
 
 @dataclass
@@ -273,4 +274,143 @@ class PodContainerDO(BaseDO):
     pod_name: str
     init_container_info: str
     container_info: str
+    _life_time: int=5
+
+@dataclass
+class KeyToPathDO(BaseDO):
+    key: str
+    path: str
+    mode: Optional[int]=None
+
+@dataclass
+class PodSecurityContextDO(BaseDO):
+    run_as_user: Optional[int]=None
+    run_as_group: Optional[int]=None
+    run_as_non_root: Optional[bool]=None
+
+@dataclass
+class EnvVarSourceDO(BaseDO):
+    env_var_source_type: str
+    key: str
+    name: str
+    optional: Optional[bool]=None
+
+@dataclass
+class EnvVarDO(BaseDO):
+    name: str
+    value_from: Optional[EnvVarSourceDO] = None
+    value: Optional[str]=None
+
+@dataclass
+class VolumeSourceDO(BaseDO):
+    name: str  
+    volume_type: str
+    default_mode: Optional[int] = None
+    items: Optional[List[KeyToPathDO]] = None
+    optional: Optional[bool] = None
+
+@dataclass
+class VolumeSettingDO(BaseDO):
+    volume_name: str
+    empty_dir: Optional[bool] = None
+    config_map: Optional[VolumeSourceDO] = None
+    secret: Optional[VolumeSourceDO] = None
+
+@dataclass
+class VolumeMountDO(BaseDO):
+    name: str
+    mount_path: str
+    read_only: Optional[bool]=None
+    sub_path: Optional[str]=None
+
+@dataclass
+class ContainerPortDO(BaseDO):
+    port: int
+    name: Optional[str] = None
+    protocol: Optional[str] = None
+    host_ip: Optional[str] = None
+    host_port: Optional[int] = None
+
+@dataclass
+class HTTPGetActionDO(BaseDO):
+    port: int
+    host: Optional[str] = None
+    path: Optional[str] = None
+    http_headers: Optional[List[Dict]] = None
+    scheme: Optional[str] = None
+
+@dataclass
+class TCPSocketActionDO(BaseDO):
+    port: int
+    host: Optional[str] = None
+
+@dataclass
+class GRPCActionDO(BaseDO):
+    port: int
+    service: Optional[str] = None
+
+@dataclass
+class ProbeDO(BaseDO):
+    initial_delay_seconds: int = 10
+    period_seconds: int = 10
+    success_threshold: Optional[int] = None
+    timeout_seconds: int = 1
+    command: Optional[List[str]] = None
+    failure_threshold: int = 3
+    grpc: Optional[GRPCActionDO] = None
+    http_get: Optional[HTTPGetActionDO] = None
+    tcp_socket: Optional[TCPSocketActionDO] = None
+
+@dataclass
+class LabelSelectorRequirementDO(BaseDO):
+    key: str
+    operator: str
+    values: Optional[List[str]] = None
+
+@dataclass
+class LabelSelectorDO(BaseDO):
+    match_expressions: Optional[List[LabelSelectorRequirementDO]] = None
+    match_labels: Optional[Dict] = None
+
+@dataclass
+class ContainerSettingDO(BaseDO):
+    container_name: str
+    container_image: str
+    command: Optional[List[str]] = None
+    args: Optional[List[str]] = None
+    env_vars: Optional[List[EnvVarDO]] = None
+    image_pull_policy: Optional[str] = None
+    working_dir: Optional[str] = None
+    volume_mount: Optional[List[VolumeMountDO]] = None
+    security_context: Optional[PodSecurityContextDO] = None
+    limits: Optional[Dict] = None
+    requests: Optional[Dict] = None
+    readiness_probe: Optional[ProbeDO] = None
+    liveness_probe: Optional[ProbeDO] = None
+    ports: Optional[List[ContainerPortDO]] = None
+
+@dataclass
+class JobSettingDO(BaseDO):
+    job_name: str
+    namespace_name: str
+    labels: Dict
+    containers: List[ContainerSettingDO]
+    init_containers: Optional[List[ContainerSettingDO]]
+    node_name: Optional[str] = None
+    node_selector: Optional[Dict] = None
+    parallelism: int = 1
+    ttl_seconds_after_finished: int = 600
+    restart_policy: str = 'Never'
+    backoff_limit: int = 2
+    volumes: Optional[List[VolumeSettingDO]] = None
+    selector: Optional[LabelSelectorDO] = None
+    dns_policy: Optional[str] = None
+
+@dataclass
+class JobDO(BaseDO):
+    name: str
+    age: Union[str, datetime.timedelta]
+    namespace: str
+    status: Dict
+    parallelism: int
     _life_time: int=5
\ No newline at end of file
