@@ -8,6 +8,8 @@ from .converter import(
     ConditionConverter,
     InstanceInfoConverter,
     InstanceTypeWithStatusConverter,
+    JobConverter,
+    JobSettingConverter,
     NodeInfoConverter,
     PodContainerConverter,
 )
@@ -18,6 +20,8 @@ from ..domain.entity import (
     Condition,
     InstanceInfo,
     InstanceTypeWithStatus,
+    Job,
+    JobSetting,
     Namespace,
     Deployment,
     Ingress,
@@ -34,6 +38,7 @@ from ..domain.entity import (
     Service
 )
 from ..domain.value_obj import (
+    Number,
     Key,
     Bool,
     Name,
@@ -81,6 +86,8 @@ ingress_converter = IngressConverter()
 service_converter = ServiceConverter()
 instance_info_converter = InstanceInfoConverter()
 instance_type_with_status_converter = InstanceTypeWithStatusConverter()
+job_converter = JobConverter()
+job_setting_converter = JobSettingConverter()
 
 
 class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
@@ -183,6 +190,16 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
             self.log_func(result.error_traceback)
             return False
 
+    def create_job(self, cluster_name: Name, job_setting: JobSetting)->Optional[Job]:
+        cluster_name = cluster_name.get_value()
+        job_setting = job_setting_converter.to_do(job_setting)
+        result = self.ao.create_job(cluster_name, job_setting)
+        if result.succeed:
+            return job_converter.to_entity(result.get_value())
+        else:
+            self.log_func(result.error_traceback)
+            return None
+
     def delete_nodes(self, node_infos: List[NodeInfo])->None:
         node_infos = [node_info_converter.to_do(x) for x in node_infos]
         result = self.ao.delete_nodes(node_infos)
@@ -206,7 +223,7 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
         cluster_name = cluster_name.get_value()
         namespace_name = namespace_name.get_value()
         result = self.ao.get_config_maps(cluster_name, namespace_name)
-        if result.succeed:
+        if result.succeed and result.get_value() is not None:
             return [config_map_converter.to_entity(x) for x in result.get_value()]
         else:
             self.log_func(result.error_traceback)
@@ -226,7 +243,7 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
         cluster_name = cluster_name.get_value()
         namespace_name = namespace_name.get_value()
         result = self.ao.get_deployments(cluster_name, namespace_name)
-        if result.succeed:
+        if result.succeed and result.get_value() is not None:
             return [deployment_converter.to_entity(x) for x in result.get_value()]
         else:
             self.log_func(result.error_traceback)
@@ -288,7 +305,7 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
     def _get_namespaces(self, cluster_name: Name)->Optional[List[Namespace]]:
         cluster_name = cluster_name.get_value()
         result = self.ao.get_namespaces(cluster_name)
-        if result.succeed:
+        if result.succeed and result.get_value() is not None:
             return [namespace_converter.to_entity(x) for x in result.get_value()]
         else:
             self.log_func(result.error_traceback)
@@ -325,7 +342,7 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
         cluster_name = cluster_name.get_value()
         namespace_name = namespace_name.get_value()
         result = self.ao.get_pods(cluster_name, namespace_name)
-        if result.succeed:
+        if result.succeed and result.get_value() is not None:
             return [pod_converter.to_entity(x) for x in result.get_value()]
         else:
             self.log_func(result.error_traceback)
@@ -360,7 +377,7 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
         cluster_name = cluster_name.get_value()
         namespace_name = namespace_name.get_value()
         result = self.ao.get_pod_containers(cluster_name, namespace_name)
-        if result.succeed:
+        if result.succeed and result.get_value() is not None:
             return [pod_container_converter.to_entity(x) for x in result.get_value()]
         else:
             self.log_func(result.error_traceback)
@@ -380,7 +397,7 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
         cluster_name = cluster_name.get_value()
         namespace_name = namespace_name.get_value()
         result = self.ao.get_secrets(cluster_name, namespace_name)
-        if result.succeed:
+        if result.succeed and result.get_value() is not None:
             return [secret_converter.to_entity(x) for x in result.get_value()]
         else:
             self.log_func(result.error_traceback)
@@ -409,7 +426,7 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
         cluster_name = cluster_name.get_value()
         namespace_name = namespace_name.get_value()
         result = self.ao.get_ingresses(cluster_name, namespace_name)
-        if result.succeed:
+        if result.succeed and result.get_value() is not None:
             return [ingress_converter.to_entity(x) for x in result.get_value()]
         else:
             self.log_func(result.error_traceback)
@@ -429,7 +446,7 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
         cluster_name = cluster_name.get_value()
         namespace_name = namespace_name.get_value()
         result = self.ao.get_services(cluster_name, namespace_name)
-        if result.succeed:
+        if result.succeed and result.get_value() is not None:
             return [service_converter.to_entity(x) for x in result.get_value()]
         else:
             self.log_func(result.error_traceback)
@@ -443,4 +460,38 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
             converter=None,
             cluster_name=cluster_name,
             namespace_name=namespace_name
-        )
\ No newline at end of file
+        )
+
+    def _get_jobs(self, cluster_name: Name, namespace_name: Name)->Optional[List[Job]]:
+        cluster_name = cluster_name.get_value()
+        namespace_name = namespace_name.get_value()
+        result = self.ao.get_jobs(cluster_name, namespace_name)
+        if result.succeed and result.get_value() is not None:
+            return [job_converter.to_entity(x) for x in result.get_value()]
+        else:
+            self.log_func(result.error_traceback)
+            return None
+
+    def get_jobs(self, cluster_name: Name, namespace_name: Name)->Optional[List[Job]]:
+        key = f'{cluster_name.get_value()}:{namespace_name.get_value()}:jobs'
+        return self.find_entity_helper(
+            self._get_jobs,
+            key=key,
+            converter=None,
+            cluster_name=cluster_name,
+            namespace_name=namespace_name
+        )
+    
+    def get_pod_log(
+        self, 
+        cluster_name: Name, 
+        namespace_name: Name, 
+        pod_name: Name, 
+        tail_lines: Number = Number(500)
+    ) -> Optional[str]:
+        cluster_name = cluster_name.get_value()
+        namespace_name = namespace_name.get_value()
+        pod_name = pod_name.get_value()
+        tail_lines = tail_lines.get_value()
+        return self.ao.get_pod_log(cluster_name, namespace_name, pod_name, tail_lines)
+
